// PROJECT  :T1NormalOVFISR
// PURPOSE  :(Mid-Level) Introduction to Timers, their Interrupts, and Service Routines
// DEVICE   :Arduino
// AUTHOR   :C. D'Arcy
// DATE     :2019 01 31
// uC       :328p
// COURSE   :ICS4U
// STATUS   :Working
// REFERENCE:Section 16.11: https://mail.rsgc.on.ca/~cdarcy/Datasheets/ATmega328P.pdf
// NOTES    :Consult AVR Timer Calculator:
// https://www.easycalculation.com/engineering/electrical/avr-timer-calculator.php
#include "prescalers.h"         //syntactically compatible for both Arduino IDE and AS7 
//volatile uint8_t ovfCount;    //optional use

// Macro for Timer 1 Overflow Interrupt Service Routine with predefined vector identifier
ISR(TIMER1_OVF_vect) {
  //  ovfCount++;               //optional addtional scaling
  //  if (!ovfCount)
  PORTB ^= (1 << PB5);          //toggle UNO LED
}

int main() {                    //(KIS) we'll avoid separate setup()&loop() functions
  DDRB |= (1 << PB5);           //pin 13 set for output
  //ovfCount = 0;               //optional
  cli();                        //disable global interrupt system while configuring
  TCCR1A = 0;                   //Normal Mode (start with the simplest)
  TCCR1B = T1psNone;            //no prescaler to start (full speed)
  TCNT1 = 0;                    //optional for this mode
  TIMSK1 = 1 << TOIE1;          //enable Timer1 overflow interrupt ability
  sei();                        //enable global interrupt system
  while (1);                    //enjoy the show as ISR responds to overflow interrupt(s)
}
